@@ -4,8 +4,8 @@
  */
 
 
-#ifndef _NGX_SHARED_H_INCLUDED_
-#define _NGX_SHARED_H_INCLUDED_
+#ifndef _NGX_SHMEM_H_INCLUDED_
+#define _NGX_SHMEM_H_INCLUDED_
 
 
 #include <ngx_config.h>
@@ -23,4 +23,4 @@ ngx_int_t ngx_shm_alloc(ngx_shm_t *shm);
 void ngx_shm_free(ngx_shm_t *shm);
 
 
-#endif /* _NGX_SHARED_H_INCLUDED_ */
+#endif /* _NGX_SHMEM_H_INCLUDED_ */
